import { type AxiosError, type AxiosResponse } from "axios";

import {
    axiosInstance,
    defaultApiErrorHandler,
    defaultApiSuccessHandler,
} from "@/services/api";

// Unauth API
function finalizeAccount(
    onSuccessHandler?: (response: AxiosResponse) => void,
    onErrorHandler?: (error: AxiosError) => void
): void {
    axiosInstance
        .post("/unauth/finalize")
        .then((response) => {
            if (onSuccessHandler) {
                onSuccessHandler(response);
            } else {
                defaultApiSuccessHandler(response);
            }
        })
        .catch((error: AxiosError) => {
            if (onErrorHandler) {
                onErrorHandler(error);
            } else {
                defaultApiErrorHandler(error);
            }
        });
}

// function requestJoinProject( // Not yet implemented [cite: 4]
//     projectId: number,
//     onSuccessHandler?: (response: AxiosResponse) => void,
//     onErrorHandler?: (error: AxiosError) => void
// ): void {
//     axiosInstance
//         .post(`/unauth/request-join/${projectId}`)
//          .then((response) => {
//             if (onSuccessHandler) {
//                 onSuccessHandler(response);
//             } else {
//                 defaultApiSuccessHandler(response);
//             }
//         })
//         .catch((error: AxiosError) => {
//             if (onErrorHandler) {
//                 onErrorHandler(error);
//             } else {
//                 defaultApiErrorHandler(error);
//             }
//         });
// }

function getAllEntrepreneurs(
    onSuccessHandler?: (response: AxiosResponse) => void,
    onErrorHandler?: (error: AxiosError) => void
): void {
    axiosInstance
        .get("/unauth/getAllEntrepreneurs")
        .then((response) => {
            if (onSuccessHandler) {
                onSuccessHandler(response);
            } else {
                defaultApiSuccessHandler(response);
            }
        })
        .catch((error: AxiosError) => {
            if (onErrorHandler) {
                onErrorHandler(error);
            } else {
                defaultApiErrorHandler(error);
            }
        });
}

export {
    finalizeAccount,
    getAllEntrepreneurs,
    // requestJoinProject, // Not yet implemented [cite: 4]
};
